@@ -2,14 +2,14 @@ module TomlRB
   # Used in primitive.citrus
   module BasicString
     SPECIAL_CHARS = {
-      '\\0'  => "\0",
-      '\\t'  => "\t",
-      '\\b'  => "\b",
-      '\\f'  => "\f",
-      '\\n'  => "\n",
-      '\\r'  => "\r",
-      '\\"'  => '"',
-      '\\\\' => '\\'
+      "\\0" => "\0",
+      "\\t" => "\t",
+      "\\b" => "\b",
+      "\\f" => "\f",
+      "\\n" => "\n",
+      "\\r" => "\r",
+      '\\"' => '"',
+      "\\\\" => "\\"
     }.freeze
 
     def value
@@ -21,7 +21,7 @@ module TomlRB
     # Replace the unicode escaped characters with the corresponding character
     # e.g. \u03B4 => ?
     def self.decode_unicode(str)
-      [str[2..-1].to_i(16)].pack('U')
+      [str[2..-1].to_i(16)].pack("U")
     end
 
     def self.transform_escaped_chars(str)
@@ -29,7 +29,7 @@ module TomlRB
         if m.size == 2
           SPECIAL_CHARS[m] || parse_error(m)
         else
-          decode_unicode(m).force_encoding('UTF-8')
+          decode_unicode(m).force_encoding("UTF-8")
         end
       end
     end
@@ -47,11 +47,11 @@ module TomlRB
 
   module MultilineString
     def value
-      return '' if captures[:text].empty?
+      return "" if captures[:text].empty?
       aux = captures[:text].first.value
 
       # Remove spaces on multilined Singleline strings
-      aux.gsub!(/\\\r?\n[\n\t\r ]*/, '')
+      aux.gsub!(/\\\r?\n[\n\t\r ]*/, "")
 
       TomlRB::BasicString.transform_escaped_chars aux
     end
@@ -59,10 +59,10 @@ module TomlRB
 
   module MultilineLiteral
     def value
-      return '' if captures[:text].empty?
+      return "" if captures[:text].empty?
       aux = captures[:text].first.value
 
-      aux.gsub(/\\\r?\n[\n\t\r ]*/, '')
+      aux.gsub(/\\\r?\n[\n\t\r ]*/, "")
     end
   end
 end
